/***************************************************************************
				filessettings.h  -  description
				-------------------
	begin			: Sun Apr 18 2004
	copyright		: (C) 2004 Otto Bruggeman
	email			: otto.bruggeman@home.nl

****************************************************************************/

/***************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
****************************************************************************/

#ifndef FILESSETTINGS_H
#define FILESSETTINGS_H

#include <tqstring.h>

#include "settingsbase.h"

class TDEConfig;

class FilesSettings : public SettingsBase
{
TQ_OBJECT
  
public:
	FilesSettings( TQWidget* parent );
	virtual ~FilesSettings();

public:
	// some virtual functions that will be overloaded from the base class
	virtual void loadSettings( TDEConfig* config );
	virtual void saveSettings( TDEConfig* config );

	void setGroup( const TQString& groupName );

public:
	TQString     m_configGroupName;

	TQStringList m_recentSources;
	TQString     m_lastChosenSourceURL;
	TQStringList m_recentDestinations;
	TQString     m_lastChosenDestinationURL;
	TQString     m_encoding;
};

#endif // FILESSETTINGS_H

